@@ -8,15 +8,15 @@
       record: Header + content + padding
 
     Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-    Copyright (c) 2000-2008, eGenix.com Software GmbH; mailto:info@egenix.com
+    Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
     See the documentation for further information on copyrights,
     or contact the author. All Rights Reserved.
 
 """
-import cPickle,cStringIO,struct,exceptions,types,sys,marshal,string,re
+import cPickle,cStringIO,struct,exceptions,types,sys,marshal,re
 import FileLock,Cache
 from mx import Tools
-freeze=Tools.freeze
+freeze = Tools.freeze
 from mx.Log import *
 
 # Blocksize used to improve alignment of records (NOTE: Don't change this
@@ -354,7 +354,7 @@ class BeeStorage:
         if version > self.version:
             raise Error,'wrong version: %s (expected %s)' % \
                   (version,self.version)
-        if string.atoi(blocksize) != BLOCKSIZE:
+        if int(blocksize) != BLOCKSIZE:
             raise Error,'blocksize mismatch: %s (expected %i)'  % \
                   (blocksize,BLOCKSIZE)
 
@@ -393,11 +393,11 @@ class BeeStorage:
         """
         if self.caching:
             #self.flush()
-            method_mapply(self.caches,'clear',())
+            Tools.method_mapply(self.caches,'clear',())
 
     def close(self,
 
-              COLD=COLD,method_mapply=method_mapply):
+              COLD=COLD,method_mapply=Tools.method_mapply):
 
         """ Flush buffers and close the associated file.
         """
@@ -479,7 +479,7 @@ class BeeStorage:
     def write_header(self,position,recordsize,rtype=VALID,
 
                      pack=struct.pack,
-                     join=string.join,ID=ID,HOT=HOT):
+                     ID=ID,HOT=HOT):
 
         """ Write a plain header to position.
 
@@ -495,7 +495,7 @@ class BeeStorage:
         """
         file = self.file
         file.seek(position)
-        file.write(join((ID,pack('<l',recordsize),rtype),''))
+        file.write(''.join((ID,pack('<l',recordsize),rtype)))
         
         if self.caching:
             self.header_cache.put(position,(recordsize,rtype,recordsize-6))
@@ -503,7 +503,7 @@ class BeeStorage:
     def write_record(self,data,position,minsize=0,rtype=VALID,
 
                      BLOCKSIZE=BLOCKSIZE,pack=struct.pack,
-                     join=string.join,ID=ID,HOT=HOT):
+                     ID=ID,HOT=HOT):
 
         """ Write a record of given rtype (defaults to VALID)
             containing data to position.
@@ -526,49 +526,56 @@ class BeeStorage:
             self.mark(HOT)
 
         # Record is to be updated
+        recordsize = None
+        datasize = None
         if position < EOF:
-            recordsize,rtype,datasize = self.read_header(position)
+            recordsize,rt,datasize = self.read_header(position)
             if datasize < datalen:
-                # Drop old record
-                if rtype == VALID:
+                # Mark valid record as old
+                if rt == VALID:
                     if _debug:
                         log(SYSTEM_INFO,
                             'Could not update %i record in place: '
-                            'old size = %i, datalen = %i, data = %s',
+                            'old size = %i, datalen = %i, data = %r',
                             position,datasize,datalen,data)
                     self.free(position)
                 # revert to appending...
                 position = EOF
-            else:
-                # Write new data
-                file.write(data)
-                if _debug:
-                    log(SYSTEM_INFO,'Data written to position %i: %s',
-                        position,data)
-                return position
+                recordsize = None
+                datasize = None
+                
+        elif position > EOF:
+            raise ValueError('cannot write to position outside file: '
+                             'position=%r, EOF=%r' %
+                             (position, EOF))
 
-        # Record is to be appended
-        recordsize = datalen + 6
-        if recordsize < self.min_recordsize:
-            recordsize = self.min_recordsize
-        if recordsize % BLOCKSIZE != 0:
-            recordsize = (recordsize / BLOCKSIZE + 1) * BLOCKSIZE
+        # Calculate recordsize, if not available
+        if recordsize is None:
+            recordsize = datalen + 6
+            if recordsize < self.min_recordsize:
+                recordsize = self.min_recordsize
+            if recordsize % BLOCKSIZE != 0:
+                recordsize = (recordsize / BLOCKSIZE + 1) * BLOCKSIZE
+            datasize = recordsize - 6
 
         # Write the header + data + padding
         file.seek(position)
-        file.write(join((ID,pack('<l',recordsize),rtype,        # Header
-                         data,                                  # Data
-                         '\0' * (recordsize - 6 - datalen)      # Padding
-                         ),''))
+        file.write(''.join(
+            (ID,pack('<l', recordsize), rtype,     # Header
+             data,                                 # Data
+             '\0' * (datasize - datalen)           # Padding
+             )))
         if self.caching:
-            self.header_cache.put(position,(recordsize,rtype,recordsize-6))
+            self.header_cache.put(position, (recordsize, rtype, datasize))
 
         # Update EOF
-        self.EOF = file.tell()
+        if position >= EOF:
+            self.EOF = file.tell()
+            if _debug:
+                log(SYSTEM_DEBUG,'New EOF = %i',self.EOF)
         if _debug:
-            log(SYSTEM_DEBUG,'New EOF = %i',self.EOF)
-            log(SYSTEM_DEBUG,'Data written to position %i: %s',
-                position,data)
+            log(SYSTEM_DEBUG,'Data written to position %i: %r',
+                position, data)
 
         return position
 
@@ -583,9 +590,11 @@ class BeeStorage:
             
         """
         file = self.file
-        recordsize,rt,datasize = read_header(position)
+        recordsize,rt,datasize = self.read_header(position)
         if rtype != rt:
-            raise Error,'record has wrong type'
+            raise Error(
+                'record has wrong type, expected %r, found %r' %
+                (rtype, rt))
         
         # Read the record
         return file.read(datasize)
@@ -607,7 +616,7 @@ class BeeStorage:
         file.write(OLD)
 
         if self.caching:
-            method_mapply(self.caches,'delete',(position,))
+            Tools.method_mapply(self.caches,'delete',(position,))
 
     # Aliases
     delete = free
