@@ -6,13 +6,13 @@
     other constructors silently ignore the time zone information.
 
     Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-    Copyright (c) 2000-2008, eGenix.com Software GmbH; mailto:info@egenix.com
+    Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
     See the documentation for further information on copyrights,
     or contact the author.
 
 """
 import DateTime,Timezone
-import re,string
+import re
 
 # Grammar: ISO 8601 (not all, but what we need from it)
 _year = '(?P<year>\d?\d\d\d)'
@@ -38,11 +38,11 @@ isoweektimeRE = re.compile(_weekdate + '(?:[ T]' + _time + ')?$')
 
 def WeekTime(year,isoweek=1,isoday=1,hour=0,minute=0,second=0.0):
 
-    """Week(year,isoweek=1,isoday=1,hour=0,minute=0,second=0.0)
+    """ Week(year,isoweek=1,isoday=1,hour=0,minute=0,second=0.0)
 
-       Returns a DateTime instance pointing to the given ISO week and
-       day.  isoday defaults to 1, which corresponds to Monday in the
-       ISO numbering. The time part is set as given.
+        Returns a DateTime instance pointing to the given ISO week and
+        day.  isoday defaults to 1, which corresponds to Monday in the
+        ISO numbering. The time part is set as given.
 
     """
     d = DateTime.DateTime(year,1,1,hour,minute,second)
@@ -62,228 +62,214 @@ Date = DateTime.Date
 Time = DateTime.Time
 TimeDelta = DateTime.TimeDelta
 
-def ParseDateTime(isostring,parse_isodatetime=isodatetimeRE.match,
+def ParseDateTime(isostring,parse_isodatetime=isodatetimeRE.match):
 
-                  strip=string.strip,atoi=string.atoi,atof=string.atof):
+    """ ParseDateTime(isostring)
 
-    """ParseDateTime(isostring)
+        Returns a DateTime instance reflecting the given ISO date. A
+        time part is optional and must be delimited from the date by a
+        space or 'T'.
 
-       Returns a DateTime instance reflecting the given ISO date. A
-       time part is optional and must be delimited from the date by a
-       space or 'T'.
-
-       Time zone information is parsed, but not evaluated.
+        Time zone information is parsed, but not evaluated.
 
     """
-    s = strip(isostring)
+    s = isostring.strip()
     date = parse_isodatetime(s)
     if not date:
         raise ValueError,'wrong format, use YYYY-MM-DD HH:MM:SS'
     year,month,day,hour,minute,second,zone = date.groups()
-    year = atoi(year)
+    year = int(year)
     if month is None:
         month = 1
     else:
-        month = atoi(month)
+        month = int(month)
     if day is None:
         day = 1
     else:
-        day = atoi(day)
+        day = int(day)
     if hour is None:
         hour = 0
     else:
-        hour = atoi(hour)
+        hour = int(hour)
     if minute is None:
         minute = 0
     else:
-        minute = atoi(minute)
+        minute = int(minute)
     if second is None:
         second = 0.0
     else:
-        second = atof(second)
+        second = float(second)
     return DateTime.DateTime(year,month,day,hour,minute,second)
 
-def ParseDateTimeGMT(isostring,parse_isodatetime=isodatetimeRE.match,
+def ParseDateTimeGMT(isostring,parse_isodatetime=isodatetimeRE.match):
 
-                     strip=string.strip,atoi=string.atoi,atof=string.atof):
+    """ ParseDateTimeGMT(isostring)
 
-    """ParseDateTimeGMT(isostring)
-
-       Returns a DateTime instance in UTC reflecting the given ISO
-       date. A time part is optional and must be delimited from the
-       date by a space or 'T'. Timezones are honored.
+        Returns a DateTime instance in UTC reflecting the given ISO
+        date. A time part is optional and must be delimited from the
+        date by a space or 'T'. Timezones are honored.
 
     """
-    s = strip(isostring)
+    s = isostring.strip()
     date = parse_isodatetime(s)
     if not date:
         raise ValueError,'wrong format, use YYYY-MM-DD HH:MM:SS'
     year,month,day,hour,minute,second,zone = date.groups()
-    year = atoi(year)
+    year = int(year)
     if month is None:
         month = 1
     else:
-        month = atoi(month)
+        month = int(month)
     if day is None:
         day = 1
     else:
-        day = atoi(day)
+        day = int(day)
     if hour is None:
         hour = 0
     else:
-        hour = atoi(hour)
+        hour = int(hour)
     if minute is None:
         minute = 0
     else:
-        minute = atoi(minute)
+        minute = int(minute)
     if second is None:
         second = 0.0
     else:
-        second = atof(second)
+        second = float(second)
     offset = Timezone.utc_offset(zone)
     return DateTime.DateTime(year,month,day,hour,minute,second) - offset
 
 # Alias
 ParseDateTimeUTC = ParseDateTimeGMT
 
-def ParseDate(isostring,parse_isodate=isodateRE.match,
+def ParseDate(isostring,parse_isodate=isodateRE.match):
 
-              strip=string.strip,atoi=string.atoi,atof=string.atof):
+    """ ParseDate(isostring)
 
-    """ParseDate(isostring)
-
-       Returns a DateTime instance reflecting the given ISO date. A
-       time part may not be included.
+        Returns a DateTime instance reflecting the given ISO date. A
+        time part may not be included.
 
     """
-    s = strip(isostring)
+    s = isostring.strip()
     date = parse_isodate(s)
     if not date:
         raise ValueError,'wrong format, use YYYY-MM-DD'
     year,month,day = date.groups()
-    year = atoi(year)
+    year = int(year)
     if month is None:
         month = 1
     else:
-        month = atoi(month)
+        month = int(month)
     if day is None:
         day = 1
     else:
-        day = atoi(day)
+        day = int(day)
     return DateTime.DateTime(year,month,day)
 
-def ParseWeek(isostring,parse_isoweek=isoweekRE.match,
+def ParseWeek(isostring,parse_isoweek=isoweekRE.match):
 
-              strip=string.strip,atoi=string.atoi,atof=string.atof):
+    """ ParseWeek(isostring)
 
-    """ParseWeek(isostring)
-
-       Returns a DateTime instance reflecting the given ISO date. A
-       time part may not be included.
+        Returns a DateTime instance reflecting the given ISO date. A
+        time part may not be included.
 
     """
-    s = strip(isostring)
+    s = isostring.strip()
     date = parse_isoweek(s)
     if not date:
         raise ValueError,'wrong format, use yyyy-Www-d, e.g. 1998-W01-1'
     year,week,day = date.groups()
-    year = atoi(year)
+    year = int(year)
     if week is None:
         week = 1
     else:
-        week = atoi(week)
+        week = int(week)
     if day is None:
         day = 1
     else:
-        day = atoi(day)
+        day = int(day)
     return Week(year,week,day)
 
-def ParseWeekTime(isostring,parse_isoweektime=isoweektimeRE.match,
+def ParseWeekTime(isostring,parse_isoweektime=isoweektimeRE.match):
 
-                  strip=string.strip,atoi=string.atoi,atof=string.atof):
+    """ ParseWeekTime(isostring)
 
-    """ParseWeekTime(isostring)
-
-       Returns a DateTime instance reflecting the given ISO date. A
-       time part is optional and must be delimited from the date by a
-       space or 'T'.
+        Returns a DateTime instance reflecting the given ISO date. A
+        time part is optional and must be delimited from the date by a
+        space or 'T'.
 
     """
-    s = strip(isostring)
+    s = isostring.strip()
     date = parse_isoweektime(s)
     if not date:
         raise ValueError,'wrong format, use e.g. "1998-W01-1 12:00:30"'
     year,week,day,hour,minute,second,zone = date.groups()
-    year = atoi(year)
+    year = int(year)
     if week is None:
         week = 1
     else:
-        week = atoi(week)
+        week = int(week)
     if day is None:
         day = 1
     else:
-        day = atoi(day)
+        day = int(day)
     if hour is None:
         hour = 0
     else:
-        hour = atoi(hour)
+        hour = int(hour)
     if minute is None:
         minute = 0
     else:
-        minute = atoi(minute)
+        minute = int(minute)
     if second is None:
         second = 0.0
     else:
-        second = atof(second)
+        second = float(second)
     return WeekTime(year,week,day,hour,minute,second)
 
-def ParseTime(isostring,parse_isotime=isotimeRE.match,
+def ParseTime(isostring,parse_isotime=isotimeRE.match):
 
-              strip=string.strip,atoi=string.atoi,atof=string.atof):
+    """ ParseTime(isostring)
 
-    """ParseTime(isostring)
-
-       Returns a DateTimeDelta instance reflecting the given ISO time.
-       Hours and minutes must be given, seconds are
-       optional. Fractions of a second may also be used,
-       e.g. 12:23:12.34.
+        Returns a DateTimeDelta instance reflecting the given ISO time.
+        Hours and minutes must be given, seconds are
+        optional. Fractions of a second may also be used,
+        e.g. 12:23:12.34.
 
     """
-    s = strip(isostring)
+    s = isostring.strip()
     time = parse_isotime(s)
     if not time:
         raise ValueError,'wrong format, use HH:MM:SS'
     hour,minute,second,zone = time.groups()
-    hour = atoi(hour)
-    minute = atoi(minute)
+    hour = int(hour)
+    minute = int(minute)
     if second is not None:
-        second = atof(second)
+        second = float(second)
     else:
         second = 0.0
     return DateTime.TimeDelta(hour,minute,second)
 
-def ParseTimeDelta(isostring,parse_isodelta=isodeltaRE.match,
+def ParseTimeDelta(isostring,parse_isodelta=isodeltaRE.match):
 
-                   strip=string.strip,atoi=string.atoi,atof=string.atof):
+    """ ParseTimeDelta(isostring)
 
-    """ParseTimeDelta(isostring)
-
-       Returns a DateTimeDelta instance reflecting the given ISO time
-       as delta. Hours and minutes must be given, seconds are
-       optional. Fractions of a second may also be used,
-       e.g. 12:23:12.34. In addition to the ISO standard a sign may be
-       prepended to the time, e.g. -12:34.
+        Returns a DateTimeDelta instance reflecting the given ISO time
+        as delta. Hours and minutes must be given, seconds are
+        optional. Fractions of a second may also be used,
+        e.g. 12:23:12.34. In addition to the ISO standard a sign may be
+        prepended to the time, e.g. -12:34.
 
     """
-    s = strip(isostring)
+    s = isostring.strip()
     time = parse_isodelta(s)
     if not time:
         raise ValueError,'wrong format, use [-]HH:MM:SS'
     sign,hour,minute,second,zone = time.groups()
-    hour = atoi(hour)
-    minute = atoi(minute)
+    hour = int(hour)
+    minute = int(minute)
     if second is not None:
-        second = atof(second)
+        second = float(second)
     else:
         second = 0.0
     if sign and sign == '-':
@@ -293,10 +279,10 @@ def ParseTimeDelta(isostring,parse_isodelta=isodeltaRE.match,
 
 def ParseAny(isostring):
 
-    """ParseAny(isostring)
+    """ ParseAny(isostring)
 
-       Parses the given string and tries to convert it to a
-       DateTime[Delta] instance.
+        Parses the given string and tries to convert it to a
+        DateTime[Delta] instance.
 
     """
     try:
@@ -314,12 +300,12 @@ def ParseAny(isostring):
 
 def str(datetime,tz=None):
 
-    """str(datetime,tz=DateTime.tz_offset(datetime))
+    """ str(datetime,tz=DateTime.tz_offset(datetime))
 
-       Returns the datetime instance as ISO date string. tz can be
-       given as DateTimeDelta instance providing the time zone
-       difference from datetime's zone to UTC. It defaults to
-       DateTime.tz_offset(datetime) which assumes local time.
+        Returns the datetime instance as ISO date string. tz can be
+        given as DateTimeDelta instance providing the time zone
+        difference from datetime's zone to UTC. It defaults to
+        DateTime.tz_offset(datetime) which assumes local time.
 
     """
     if tz is None:
@@ -331,10 +317,10 @@ def str(datetime,tz=None):
 
 def strGMT(datetime):
 
-    """strGMT(datetime)
+    """ strGMT(datetime)
 
-       Returns the datetime instance as ISO date string assuming it is
-       given in GMT.
+        Returns the datetime instance as ISO date string assuming it is
+        given in GMT.
 
     """
     return '%04i-%02i-%02i %02i:%02i:%02i+0000' % (
@@ -343,10 +329,10 @@ def strGMT(datetime):
 
 def strUTC(datetime):
 
-    """strUTC(datetime)
+    """ strUTC(datetime)
 
-       Returns the datetime instance as ISO date string assuming it is
-       given in UTC.
+        Returns the datetime instance as ISO date string assuming it is
+        given in UTC.
 
     """
     return '%04i-%02i-%02i %02i:%02i:%02i+0000' % (
