@@ -1,5 +1,6 @@
 #!/usr/local/bin/python -u
-            
+
+import mx.DateTime            
 from mx.DateTime import *
 from mx.DateTime import __version__
 import time,sys,traceback
@@ -14,10 +15,44 @@ if not __debug__:
 
 ### Constructors
 
+## DateTime()
+
+d = DateTime(2008,1,2, 12,13,14)
+assert d.year == 2008
+assert d.month == 1
+assert d.day == 2
+assert d.hour == 12
+assert d.minute == 13
+assert d.second == 14
+assert d.absdate == 733043
+assert d.abstime == 43994.0
+assert long(d.absdays*1000) == 733042509L
+
+# Normalization
+assert DateTime(2008,1,-1).day == 31
+assert DateTime(2008,1,-31).day == 1
+assert DateTime(2008,-1,1).month == 12
+assert DateTime(2008,-12,1).month == 1
+assert DateTime(-1,1,1).year == -1
+
+# .rebuild()
+assert id(d) != id(d.rebuild())
+assert d.rebuild(year=2000) == DateTime(2000,1,2, 12,13,14)
+assert d.rebuild(month=11) == DateTime(2008,11,2, 12,13,14)
+assert d.rebuild(day=12) == DateTime(2008,1,12, 12,13,14)
+assert d.rebuild(hour=9) == DateTime(2008,1,2, 9,13,14)
+assert d.rebuild(minute=20) == DateTime(2008,1,2, 12,20,14)
+assert d.rebuild(second=33) == DateTime(2008,1,2, 12,13,33)
+assert d.rebuild(second=35.5) == DateTime(2008,1,2, 12,13,35.5)
+assert d.rebuild(year=2000, hour=10) == DateTime(2000,1,2, 10,13,14)
+
+## Test DateTimeFromAbsDateTime()
+
 # wintertime
 t = winter = DateTimeFromAbsDateTime(729368,55931.522913)
 print t
 print repr(t)
+assert str(t) == '1997-12-10 15:32:11.52'
 
 x = float(t)
 print 'as ticks:',x
@@ -31,6 +66,7 @@ print
 t = summer = DateTimeFromAbsDateTime(729200,55931.522913)
 print t
 print repr(t)
+assert str(t) == '1997-06-25 15:32:11.52'
 
 x = float(t)
 print 'as ticks:',x
@@ -40,18 +76,24 @@ print 'tuple:',t.tuple()
 
 print
 
+## Test Timestamp()
 t = Timestamp(1900,1,1,12,23,34.5)
 print t
 assert t.tuple()[:6] == (1900,1,1,12,23,34)
+assert str(t) == '1900-01-01 12:23:34.50'
 
+## Test DateTimeFromCOMDate()
 t = DateTimeFromCOMDate(12345.6)
 print t
 assert t.COMDate() == 12345.6
+assert str(t) == '1933-10-18 14:24:00.00'
 
 t = DateTimeFromCOMDate(-12345.6)
 print t
 assert t.COMDate() == -12345.6
+assert str(t) == '1866-03-13 14:24:00.00'
 
+## Test DateTimeFromTicks()
 x = time.time()
 print 'ticks:',x,'localtime:',time.localtime(x)
 t = DateTimeFromTicks(x)
@@ -59,6 +101,55 @@ print t.tuple(), t.absdate, t.abstime
 assert t.ticks() == x
 print
 
+## Test Date()
+t = Date(2007,1,1)
+#print t
+assert str(t) == '2007-01-01 00:00:00.00'
+assert t.absdate == 732677
+assert t.date == '2007-01-01'
+assert t.time == '00:00:00.00'
+
+# Negative days count from the month's end
+t = Date(2007,1,-1)
+#print t
+assert str(t) == '2007-01-31 00:00:00.00'
+assert t.absdate == 732707
+assert t.date == '2007-01-31'
+assert t.time == '00:00:00.00'
+t = Date(2007,2,-1)
+#print t
+assert t.absdate == 732735
+assert t.date == '2007-02-28'
+assert t.time == '00:00:00.00'
+
+## Test now()
+t1 = now()
+time.sleep(0.1)
+t2 = now()
+if t1 == t2:
+    print 'WARNING: now() does not provide sub-second accuracy'
+else:
+    # Report now_resolution
+    if hasattr(mx.DateTime, 'now_resolution'):
+        print ('now() resolution reported by the system: '
+               '%f microseconds' % (now_resolution * 1e6))
+
+    # Test now() resolution
+    min_t_diff = 1.0
+    current_time = now
+    for i in range(1000):
+        t1, t2 = current_time(), current_time()
+        t_diff = abs(t2.abstime - t1.abstime)
+        if t_diff < min_t_diff:
+            min_t_diff = t_diff
+    if min_t_diff > 0:
+        print ('now() resolution measured as < %f microseconds'
+               % (min_t_diff * 1e6))
+    else:
+        print 'now() resolution cannot be determined'
+
+
+print
 print 'Basic constructors ok.'
 
 ### String format
@@ -66,44 +157,119 @@ t = DateTime(-1,1,1,12,34,56.78)
 assert str(t) == '-0001-01-01 12:34:56.78'
 t = DateTime(2007,1,1,12,34,56.78)
 assert str(t) == '2007-01-01 12:34:56.78'
+t = DateTime(2011,1,1,12,34,3.42)
+# Note: 3.42 is stored as 3.4199999999999999
+assert str(t) == '2011-01-01 12:34:03.42', str(t)
+assert repr(t).find( '2011-01-01 12:34:03.42') > 0
+assert t.date == '2011-01-01'
+assert t.time == '12:34:03.42'
+t = DateTime(2011,1,1,12,34,3.425)
+# Note: 3.425 is stored as 3.4249999999999998
+assert str(t) == '2011-01-01 12:34:03.43', str(t)
+assert repr(t).find( '2011-01-01 12:34:03.43') > 0
+assert t.date == '2011-01-01'
+assert t.time == '12:34:03.43'
+t = DateTime(2011,1,1,12,34,56.1147)
+# Note: 56.1147 is stored as 56.114699999999999
+assert str(t) == '2011-01-01 12:34:56.11', str(t)
+assert repr(t).find( '2011-01-01 12:34:56.11') > 0
+assert t.date == '2011-01-01'
+assert t.time == '12:34:56.11'
+t = DateTime(2011,1,1,12,34,56.124449)
+# Note: 56.124449 is stored as 56.124448999999998
+assert str(t) == '2011-01-01 12:34:56.12', str(t)
 print 'String format ok.'
 
 ### Python Number protocol:
 t1 = Date(1997,12,31)
 t2 = Date(1997,12,30)
-d = t2 - t1
+assert int(t1) == int(t1.ticks())
+d1 = t1 - t2
+assert int(d1) == 86400
+d2 = t2 - t1
+assert int(d2) == -86400
 try:
     t1 + t2
 except TypeError:
     pass
+else:
+    raise TypeError('DateTime+DateTime should not work')
 try:
     t2 * t1
 except TypeError:
     pass
+else:
+    raise TypeError('DateTime*DateTime should not work')
 try:
     t2 / t1
 except TypeError:
     pass
+else:
+    raise TypeError('DateTime/DateTime should not work')
+
 print 'Number protocol ok.'
 
 ### Deltas
+
+# Constructors
 assert DateTimeDelta(2,1,-1,-3).tuple() == (2, 0, 58, 57.0)
 assert DateTimeDelta(2,0,-1,-3).tuple() == (1, 23, 58, 57.0)
+
+# .rebuild()
+t = DateTimeDelta(2, 12, 13, 14)
+assert id(t) != id(t.rebuild())
+assert t.rebuild(day=2000) == DateTimeDelta(2000, 12,13,14)
+assert t.rebuild(hour=9) == DateTimeDelta(2, 9, 13, 14)
+assert t.rebuild(minute=20) == DateTimeDelta(2, 12, 20, 14)
+assert t.rebuild(second=33) == DateTimeDelta(2, 12, 13, 33)
+assert t.rebuild(second=35.5) == DateTimeDelta(2, 12, 13, 35.5)
+assert t.rebuild(hour=20, second=10) == DateTimeDelta(2, 20, 13, 10)
+
+# DateTime calculations
 assert DateTime(1998,1,9) + DateTimeDelta(-1) == DateTime(1998,1,8)
 assert DateTime(1998,1,9) - DateTimeDelta(1) == DateTime(1998,1,8)
 assert DateTime(1998,1,9) - DateTimeDelta(1.5) == DateTime(1998,1,7,12,0,0)
 assert DateTime(1998,1,9) - DateTime(1969,4,6) == DateTimeDelta(10505)
-assert DateTimeDelta(10000) / (DateTimeDelta(10000) * 0.5) == 2.0
 assert DateTime(2000,12,31) + DateTimeDelta(1) == DateTime(2001, 1, 1)
 assert DateTime(2000,12,31) + DateTimeDelta(2) == DateTime(2001, 1, 2)
+
+# Integer calculations
 assert DateTime(2000,12,31) + 1 == DateTime(2001, 1, 1)
 assert DateTime(2000,12,31) + 2 == DateTime(2001, 1, 2)
+
+# DateTimeDelta calculations
+assert DateTimeDelta(10000) / (DateTimeDelta(10000) * 0.5) == 2.0
+
+# Attributes
 a = Date(2000,11,9)
 b = Date(2000,11,10)
-assert (b-a).seconds == 86400.0
-assert (b-a).day == 1
-assert (b-a).hour == 0
-assert (b-a).second == 0
+d1 = b - a
+d2 = a - b
+assert d1.seconds == 86400.0
+assert d1.day == 1
+assert d1.hour == 0
+assert d1.second == 0
+assert d2.seconds == -86400.0
+
+# Number protocol
+assert int(d1) == 86400
+assert int(d2) == -86400
+
+assert int(d1 * 3) == 86400 * 3
+assert int(3 * d1) == 86400 * 3
+
+assert int(d1 + d2) == 0
+assert int(d2 + d1) == 0
+assert int(d1 - d2) == 86400 * 2, d1 - d2
+assert int(d2 - d1) == -86400 * 2, d2 - d1
+
+try:
+    d2 * d1
+except TypeError:
+    pass
+else:
+    raise TypeError('DateTimeDelta*DateTimeDelta should not work')
+
 print 'Deltas ok.'
 print
 
@@ -142,7 +308,18 @@ print 'diff =',t-c,'in seconds:',t.second - c.second
 print 'using cmp(,,0.5):',(cmp(t,c,0.5) == 0) * 'equal' or 'not equal'
 print
 
-# Sanity check
+### Julian calendar
+
+t = JulianDateTime(1752, 9, 2)
+assert t.tuple()[:3] == (1752, 9, 2)
+assert t.date == '1752-09-02'
+assert t.calendar == 'Julian'
+g = t.Gregorian()
+assert g.tuple()[:3] == (1752, 9, 13)
+assert g.date == '1752-09-13'
+assert g.calendar == 'Gregorian'
+
+### Constructor tests
 
 def testjdn(year,month,day):
 
@@ -258,6 +435,18 @@ except SystemError:
     print 'error in case you pass a DST flag other than -1.'
     print '-'*72
 
+# Check for bug #707
+epoch = DateTimeFromTicks(0)
+one_second_before_epoch = epoch - oneSecond
+two_seconds_before_epoch = epoch - 2*oneSecond
+try:
+    assert two_seconds_before_epoch.ticks() == -2
+except Error:
+    print 'Negative ticks are not support by the C lib mktime().'
+else:
+    assert one_second_before_epoch.ticks() == -1
+    print 'Negative ticks are supported by the C lib mktime().'
+
 # Sanity checks
 date1 = Date(2000,11,1) + \
         RelativeDateTime(day=1,month=1,hour=0,minute=0,second=0)
@@ -320,6 +509,38 @@ assert str(RelativeDateTime(hours=0.5)) == 'YYYY-MM-DD (+00):(+30):SS'
 assert str(RelativeDateTime(hours=-0.5)) == 'YYYY-MM-DD (+00):(-30):SS'
 print 'done.'
 
+# DateTimeFrom()
+print 'DateTimeFrom()...',
+assert (DateTimeFrom(hour=12, minute=3, defaultdate=today()-1) ==
+        today() - 1 + TimeDelta(12, 3))
+assert (DateTimeFrom(month=12, day=1, defaultdate=DateTime(2009, 1, 1, 12)) ==
+        DateTime(2009, 12, 1, 12))
+assert (DateTimeFrom("12:03", defaultdate=today()-1) ==
+        today() - 1 + TimeDelta(12, 3))
+#assert (DateTimeFrom("Dec 1", defaultdate=DateTime(2009, 1, 1, 12)) ==
+#        DateTime(2009, 12, 1, 12))
+assert (DateTimeFrom("Dec 1", defaultdate=DateTime(2009, 1, 13)) ==
+        DateTime(2009, 12, 1))
+print 'done.'
+
+# gmtime()
+print
+print 'Testing gmtime()...',
+t = 2**31 - 100
+for t, refdate in ((2**31, DateTime(2038, 1, 19, 3, 14, 8)),
+                   (2**32, DateTime(2106, 2, 7, 6, 28, 16)),
+                   (2**33, DateTime(2242, 3, 16, 12, 56, 32)),
+                   (2**34, DateTime(2514, 5, 30, 1, 53, 4)),
+                   ):
+    for i in range(-100, 100):
+        try:
+            x = gmtime(t + i)
+            assert x == refdate + i*oneSecond, (t, i, refdate)
+        except ValueError, reason:
+            print 'Failed for %s: %s + %i seconds' % (t + i, refdate, i)
+            break
+print 'done.'
+
 # timegm() emulation
 print
 print 'Testing .gmticks()... (this can take up to a few minutes)'
@@ -355,6 +576,16 @@ assert oops == 0
 print '...Works.'
 print
 
+# Test PyDateTime integration
+print 'Running Python datetime module integration tests.'
+from mx.DateTime.mxDateTime import testpydatetime
+print
+
+# Run slot operations tests
+print 'Running slot operation tests.'
+from mx.DateTime.mxDateTime import testslotops
+print
+
 # Try importing a subpackage
 print 'Importing subpackage Feasts.'
 print
