@@ -15,9 +15,12 @@
     c = a string
 
     Entries in square brackets indicate new subsections. Global
-    variables may be set prior to starting any subsection. Emtpy lines
-    and lines starting with '#' (comments) are ignored. Indentation is
-    not necessary; lines can start at any column.
+    variables may be set prior to starting any subsection.
+
+    Empty lines and lines starting with '#' or ';' (comments) are
+    ignored.
+
+    Indentation is not necessary; lines can start at any column.
 
     Entries may span multiple lines by using '\' continuations
     at the line ends, e.g.
@@ -72,16 +75,21 @@
         characters and spanning multiple lines)
 
     Copyright (c) 2000, Marc-Andre Lemburg; All Rights Reserved.
-    Copyright (c) 2000-2007, eGenix.com Software GmbH; All Rights Reserved.
+    Copyright (c) 2000-2010, eGenix.com Software GmbH; All Rights Reserved.
     See the documentation for further information on copyrights,
     or contact the author. All Rights Reserved.
 
 """
-import string,copy,re,types,exceptions,sys,os
+import copy,re,types,exceptions,sys,os
 import mx.Tools.NewBuiltins
 from mx.Tools import freeze
 import Namespace
 
+### Globals
+
+# Characters declaring comment lines
+COMMENT_CHARS = ('#', ';')
+
 # Print debug information ?
 _debug = 0
 
@@ -96,7 +104,7 @@ shell_var = re.compile('(?:\$([a-zA-Z0-9._]+)|\${([^}]*)})')
 
 def expand_vars(text,locals,globals,
 
-                split=string.split,shell_var=shell_var):
+                shell_var=shell_var):
 
     """ Expands all variables of the form $var or ${var} using
         the dictionaries locals,globals,os.environ in that order
@@ -111,7 +119,7 @@ def expand_vars(text,locals,globals,
         if not m:
             break
         g = m.groups()
-        varpath = split(g[0] or g[1],'.')
+        varpath = (g[0] or g[1]).split('.')
         varname = varpath[0]
         # Find object with name varname
         value = locals.get(varname,None)
@@ -186,7 +194,7 @@ class Entry:
 
     def pre_process(self,text,locals,globals,
 
-                    strip=string.strip,expand_vars=expand_vars):
+                    expand_vars=expand_vars):
 
         """ Preprocess the text value.
 
@@ -194,7 +202,7 @@ class Entry:
             apply variable expansion.
 
         """
-        return expand_vars(strip(text),locals,globals)
+        return expand_vars(text.strip(),locals,globals)
 
     def post_process(self,value,locals,globals):
 
@@ -255,15 +263,15 @@ class StringEntry(Entry):
 
 def comma_list(text,
 
-               strip=string.strip,split=string.split,map=map,tuple=tuple):
+               map=map,tuple=tuple):
 
-    return map(strip,split(text,','))
+    return [x.strip() for x in text.split(',')]
 
 def spaced_list(text,
 
-                strip=string.strip,split=string.split,map=map,tuple=tuple):
+                map=map,tuple=tuple):
 
-    return map(strip,split(text))
+    return [x.strip() for x in text.split()]
 
 class TupleEntry(Entry):
 
@@ -794,7 +802,7 @@ class ConfigFile:
 
     def read(self,file,
 
-             strip=string.strip,deepcopy=copy.deepcopy):
+             deepcopy=copy.deepcopy):
 
         """ Read and parse the open file.
 
@@ -816,8 +824,8 @@ class ConfigFile:
             lineno = lineno + 1
             if not line:
                 break
-            line = strip(line)
-            if not line or line[0] == '#':
+            line = line.strip()
+            if not line or line[0] in COMMENT_CHARS:
                 # Comment or emtpy line: ignore
                 continue
 
@@ -833,7 +841,7 @@ class ConfigFile:
                     # EOF: end of continuation
                     line = line[:-1]
                     break
-                nextline = strip(nextline)
+                nextline = nextline.strip()
                 if not nextline:
                     # Empty line: end of continuation
                     line = line[:-1]
