@@ -1,13 +1,11 @@
 """ A pure Python Stack implementation modelled after mxStack.
 
     Copyright (c) 2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-    Copyright (c) 2000-2008, eGenix.com Software GmbH; mailto:info@egenix.com
+    Copyright (c) 2000-2010, eGenix.com Software GmbH; mailto:info@egenix.com
     See the documentation for further information on copyrights,
     or contact the author. All Rights Reserved.
 """
 
-import string
-
 class UserStack:
 
     def __init__(self):
@@ -47,7 +45,7 @@ class UserStack:
         while len(s) != 0:
             l.append(repr(s[0]))
             s = s[1]
-        return '<UserStack [%s]>' % string.join(l,', ')
+        return '<UserStack [%s]>' % ', '.join(l)
 
     def __str__(self):
 
