@@ -3,12 +3,12 @@
 """ HTML - tag a HTML string (Version 0.6)
     
     Copyright (c) 2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-    Copyright (c) 2000-2008, eGenix.com Software GmbH; mailto:info@egenix.com
+    Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
     See the documentation for further information on copyrights,
     or contact the author. All Rights Reserved.
 """
 
-import sys,string
+import sys
 
 # constants + engine
 from mx.TextTools import *
@@ -135,7 +135,7 @@ if __name__ == '__main__':
     text = f.read()
 
     try:
-        count = string.atoi(sys.argv[2])
+        count = int(sys.argv[2])
     except:
         count = 1000
     
