@@ -16,10 +16,14 @@
   MAL_MEM_DEBUG -- enable malloc output (new,cnew,free,...) [mxstdlib.h]
 
   Copyright (c) 2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2004, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author.
 
+  XXX Most of these macros and defines should really use an mx prefix to
+      avoid collisions with native Python macros and defines. So far this
+      has not happened, which is why this hasn't been implemented yet.
+
 */
 
 /* --- Platform or compiler specific tweaks ------------------------------- */
@@ -112,8 +116,8 @@
 #ifdef MAL_REF_DEBUG
 
 static void mx_Py_INCREF(PyObject *v,
-			 char *name,
-			 char *filename,
+			 const char *name,
+			 const char *filename,
 			 int lineno)
 {
     if (!Py_DebugFlag) {
@@ -133,8 +137,8 @@ static void mx_Py_INCREF(PyObject *v,
 }
 
 static void mx_Py_DECREF(PyObject *v,
-			 char *name,
-			 char *filename,
+			 const char *name,
+			 const char *filename,
 			 int lineno) 
 {
     if (!Py_DebugFlag) {
@@ -160,8 +164,8 @@ static void mx_Py_DECREF(PyObject *v,
 }
 
 static void mx_Py_PRINT_REFCOUNT(PyObject *v,
-				 char *name,
-				 char *filename,
+				 const char *name,
+				 const char *filename,
 				 int lineno) 
 {
     if (!v)
@@ -228,10 +232,13 @@ static void mx_Py_PRINT_REFCOUNT(PyObject *v,
 #define Py_Get7Args(format,a1,a2,a3,a4,a5,a6,a7) {if (!PyArg_ParseTuple(args,format,&a1,&a2,&a3,&a4,&a5,&a6,&a7)) goto onError;}
 #define Py_Get8Args(format,a1,a2,a3,a4,a5,a6,a7,a8) {if (!PyArg_ParseTuple(args,format,&a1,&a2,&a3,&a4,&a5,&a6,&a7,&a8)) goto onError;}
 
+/* The keywords array string type */
+#define Py_KEYWORDS_STRING_TYPE char
+
 /* For functions with keywords -- the first macro parameter must be
    the keywords array given as e.g.
 
-   static char *keywords[] = {"first","second","third", 0};
+   static const char *keywords[] = {"first","second","third", 0};
 
    with an entry for every argument (in the correct order). The
    functions must be included in the method list using
@@ -285,14 +292,14 @@ static void mx_Py_PRINT_REFCOUNT(PyObject *v,
     }
 
 */
-#define Py_KeywordsGetArg(format,a1) {static char *kwslist[] = {#a1,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1)) goto onError;}
-#define Py_KeywordsGet2Args(format,a1,a2) {static char *kwslist[] = {#a1,#a2,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1,&a2)) goto onError;}
-#define Py_KeywordsGet3Args(format,a1,a2,a3) {static char *kwslist[] = {#a1,#a2,#a3,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1,&a2,&a3)) goto onError;}
-#define Py_KeywordsGet4Args(format,a1,a2,a3,a4) {static char *kwslist[] = {#a1,#a2,#a3,#a4,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1,&a2,&a3,&a4)) goto onError;}
-#define Py_KeywordsGet5Args(format,a1,a2,a3,a4,a5) {static char *kwslist[] = {#a1,#a2,#a3,#a4,#a5,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1,&a2,&a3,&a4,&a5)) goto onError;}
-#define Py_KeywordsGet6Args(format,a1,a2,a3,a4,a5,a6) {static char *kwslist[] = {#a1,#a2,#a3,#a4,#a5,#a6,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1,&a2,&a3,&a4,&a5,&a6)) goto onError;}
-#define Py_KeywordsGet7Args(format,a1,a2,a3,a4,a5,a6,a7) {static char *kwslist[] = {#a1,#a2,#a3,#a4,#a5,#a6,#a7,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1,&a2,&a3,&a4,&a5,&a6,&a7)) goto onError;}
-#define Py_KeywordsGet8Args(format,a1,a2,a3,a4,a5,a6,a7,a8) {static char *kwslist[] = {#a1,#a2,#a3,#a4,#a5,#a6,#a7,#a8,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1,&a2,&a3,&a4,&a5,&a6,&a7,&a8)) goto onError;}
+#define Py_KeywordsGetArg(format,a1) {static Py_KEYWORDS_STRING_TYPE *kwslist[] = {#a1,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1)) goto onError;}
+#define Py_KeywordsGet2Args(format,a1,a2) {static Py_KEYWORDS_STRING_TYPE *kwslist[] = {#a1,#a2,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1,&a2)) goto onError;}
+#define Py_KeywordsGet3Args(format,a1,a2,a3) {static Py_KEYWORDS_STRING_TYPE *kwslist[] = {#a1,#a2,#a3,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1,&a2,&a3)) goto onError;}
+#define Py_KeywordsGet4Args(format,a1,a2,a3,a4) {static Py_KEYWORDS_STRING_TYPE *kwslist[] = {#a1,#a2,#a3,#a4,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1,&a2,&a3,&a4)) goto onError;}
+#define Py_KeywordsGet5Args(format,a1,a2,a3,a4,a5) {static Py_KEYWORDS_STRING_TYPE *kwslist[] = {#a1,#a2,#a3,#a4,#a5,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1,&a2,&a3,&a4,&a5)) goto onError;}
+#define Py_KeywordsGet6Args(format,a1,a2,a3,a4,a5,a6) {static Py_KEYWORDS_STRING_TYPE *kwslist[] = {#a1,#a2,#a3,#a4,#a5,#a6,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1,&a2,&a3,&a4,&a5,&a6)) goto onError;}
+#define Py_KeywordsGet7Args(format,a1,a2,a3,a4,a5,a6,a7) {static Py_KEYWORDS_STRING_TYPE *kwslist[] = {#a1,#a2,#a3,#a4,#a5,#a6,#a7,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1,&a2,&a3,&a4,&a5,&a6,&a7)) goto onError;}
+#define Py_KeywordsGet8Args(format,a1,a2,a3,a4,a5,a6,a7,a8) {static Py_KEYWORDS_STRING_TYPE *kwslist[] = {#a1,#a2,#a3,#a4,#a5,#a6,#a7,#a8,NULL}; if (!PyArg_ParseTupleAndKeywords(args,kws,format,kwslist,&a1,&a2,&a3,&a4,&a5,&a6,&a7,&a8)) goto onError;}
 
 /* --- Returning values to Python ----------------------------------------- */
 
@@ -324,15 +331,22 @@ static void mx_Py_PRINT_REFCOUNT(PyObject *v,
 
 /* --- Declaring Python builtin functions/methods ------------------------- */
 
+/* The doc-string type changed to const char* in Python 2.5 */
+#if PY_VERSION_HEX >= 0x02050000
+# define Py_DOC_STRING_TYPE const char
+#else
+# define Py_DOC_STRING_TYPE char
+#endif
+
 /* Declare C function/method fct, having docstring docstr; may use vargargs */
 #define Py_C_Function(fct,docstr) \
-        static char fct##_docstring[] = docstr;\
+        static Py_DOC_STRING_TYPE fct##_docstring[] = docstr;\
         static PyObject *fct(PyObject *self, PyObject *args)
 
 /* Declare C function/method fct, having keywords keywordsarray and a
    docstring docstr; may use vargargs & keywords */
 #define Py_C_Function_WithKeywords(fct,docstr) \
-        static char fct##_docstring[] = docstr;\
+        static Py_DOC_STRING_TYPE fct##_docstring[] = docstr;\
         static PyObject *fct(PyObject *self, PyObject *args, PyObject *kws)
 
 /* These declare: self -- instance pointer for methods, NULL for functions
@@ -403,7 +417,8 @@ static void mx_Py_PRINT_REFCOUNT(PyObject *v,
 #define PyFloat_Compatible(obj)					\
         (PyInstance_Check(obj) 					\
 	 ? PyObject_HasAttrString(obj, "__float__")		\
-	 : (obj->ob_type->tp_as_number->nb_float != NULL))
+	 : (obj->ob_type->tp_as_number != NULL &&		\
+            obj->ob_type->tp_as_number->nb_float != NULL))
 
 /* --- Text macros -------------------------------------------------------- */
 
