@@ -4,7 +4,7 @@
   mxTextTools -- Fast text manipulation routines
 
   Copyright (c) 2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2008, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
 */
 
 /* The extension's name; must be the same as the init function's suffix */
@@ -131,8 +131,8 @@ typedef struct {
     int cmd;				/* Command integer */
     int flags;				/* Command flags */
     PyObject *args;			/* Command arguments */
-    int jne;				/* Non-match jump offset */
-    int je;				/* Match jump offset */
+    Py_ssize_t jne;			/* Non-match jump offset */
+    Py_ssize_t je;			/* Match jump offset */
 } mxTagTableEntry;
 
 #define MXTAGTABLE_STRINGTYPE	0
