@@ -5,7 +5,7 @@
   8-bit strings and Unicode by setting the TE_* defines appropriately.
 
   Copyright (c) 2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
 */
 
 
@@ -342,7 +342,7 @@ int TE_ENGINE_API(PyObject *textobj,
 
 		{
 		    register TE_CHAR *tx = &text[x];
-		    unsigned char *m = PyString_AS_STRING(match);
+		    unsigned char *m = (unsigned char *)PyString_AS_STRING(match);
 
 		    DPRINTF("\nAllInSet :\n"
 			    " looking for   = set at 0x%lx\n"
@@ -361,7 +361,7 @@ int TE_ENGINE_API(PyObject *textobj,
 
 		{
 		    register TE_CHAR *tx = &text[x];
-		    unsigned char *m = PyString_AS_STRING(match);
+		    unsigned char *m = (unsigned char *)PyString_AS_STRING(match);
 
 		    DPRINTF("\nIsInSet :\n"
 			    " looking for   = set at 0x%lx\n"
@@ -1033,11 +1033,11 @@ int TE_ENGINE_API(PyObject *textobj,
 			goto onError;
 		    Py_INCREF(textobj);
 		    PyTuple_SET_ITEM(args,0,textobj);
-		    w = PyInt_FromLong(start);
+		    w = PyInt_FromSsize_t(start);
 		    if (!w)
 			goto onError;
 		    PyTuple_SET_ITEM(args,1,w);
-		    w = PyInt_FromLong(sliceright);
+		    w = PyInt_FromSsize_t(sliceright);
 		    if (!w)
 			goto onError;
 		    PyTuple_SET_ITEM(args,2,w);
@@ -1197,8 +1197,8 @@ int TE_HANDLE_MATCH(int flags,
 
 	Py_INCREF(tagobj);
 	PyTuple_SET_ITEM(w,0,tagobj);
-	PyTuple_SET_ITEM(w,1,PyInt_FromLong(match_left));
-	PyTuple_SET_ITEM(w,2,PyInt_FromLong(match_right));
+	PyTuple_SET_ITEM(w,1,PyInt_FromSsize_t(match_left));
+	PyTuple_SET_ITEM(w,2,PyInt_FromSsize_t(match_right));
 	Py_INCREF(subtags);
 	PyTuple_SET_ITEM(w,3,subtags);
 
@@ -1252,8 +1252,8 @@ int TE_HANDLE_MATCH(int flags,
 	PyTuple_SET_ITEM(args,0,taglist);
 	Py_INCREF(textobj);
 	PyTuple_SET_ITEM(args,1,textobj);
-	PyTuple_SET_ITEM(args,2,PyInt_FromLong(match_left));
-	PyTuple_SET_ITEM(args,3,PyInt_FromLong(match_right));
+	PyTuple_SET_ITEM(args,2,PyInt_FromSsize_t(match_left));
+	PyTuple_SET_ITEM(args,3,PyInt_FromSsize_t(match_right));
 	Py_INCREF(subtags);
 	PyTuple_SET_ITEM(args,4,subtags);
 	if (context) {
@@ -1279,8 +1279,8 @@ int TE_HANDLE_MATCH(int flags,
 
 	Py_INCREF(Py_None);
 	PyTuple_SET_ITEM(w,0,Py_None);
-	PyTuple_SET_ITEM(w,1,PyInt_FromLong(match_left));
-	PyTuple_SET_ITEM(w,2,PyInt_FromLong(match_right));
+	PyTuple_SET_ITEM(w,1,PyInt_FromSsize_t(match_left));
+	PyTuple_SET_ITEM(w,2,PyInt_FromSsize_t(match_right));
 	Py_INCREF(subtags);
 	PyTuple_SET_ITEM(w,3,subtags);
 
