@@ -3,12 +3,12 @@
     Relies on mx.TextTools and mx.Tools.
 
     Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-    Copyright (c) 2000-2008, eGenix.com Software GmbH; mailto:info@egenix.com
+    Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
     See the documentation for further information on copyrights,
     or contact the author. All Rights Reserved.
 
 """
-import string,mimetypes
+import mimetypes
 
 from mx import Tools,TextTools
 
@@ -113,8 +113,8 @@ def escape(urltext,unsafe_charset=_modinit.unsafe_charset,
 def unescape(urltext,
 
              charsplit=TextTools.charsplit,
-             join=TextTools.join,chr=chr,atoi=string.atoi,
-             irange=irange,len=len,trange=trange):
+             join=TextTools.join,chr=chr,int=int,
+             irange=Tools.irange,len=len,trange=Tools.trange):
 
     """ Unescape a URL text part containing %xx-character encodings
 
@@ -124,7 +124,7 @@ def unescape(urltext,
     hl = charsplit(urltext,'%')
     if len(hl) > 1:
         for i,text in irange(hl,trange(1,len(hl))):
-            hl[i] = chr(atoi(text[:2],16)) + text[2:]
+            hl[i] = chr(int(text[:2],16)) + text[2:]
         return join(hl,'')
     return urltext
 
@@ -138,7 +138,7 @@ def rpcencode(name,args=(),kws=None,prefix='',encode=1,
 
               urlencode=urlencode,join=TextTools.join,
               rpc_unsafe_charset=_modinit.rpc_unsafe_charset,
-              irange=irange,tuple=tuple):
+              irange=Tools.irange,tuple=tuple):
 
     """ Return a string encoding a call of name with the given string
         arguments given in tuple args and dict kws (may be None).
@@ -214,7 +214,7 @@ def rpcdecode(url,prefix='',decode=1,
         args = charsplit(rawargs,',')
         if '=' in rawargs:
             kws = {}
-            for i,arg in reverse(irange(args)):
+            for i,arg in Tools.reverse(Tools.irange(args)):
                 if '=' in arg:
                     k,v = splitat(arg,'=')
                     kws[k] = v
