@@ -4,7 +4,7 @@
   mxURL -- A URL datatype.
 
   Copyright (c) 2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2008, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author (mailto:mal@lemburg.com).
   
@@ -54,16 +54,16 @@ typedef struct {
        and the length indicates how many characters make up that
        field. */
 
-    short netloc;		/* network location */
-    short netloc_len;
-    short path;			/* path */
-    short path_len;
-    short params;		/* parameters */
-    short params_len;
-    short query;		/* query */
-    short query_len;
-    short fragment;		/* fragment */
-    short fragment_len;
+    Py_ssize_t netloc;		/* network location */
+    Py_ssize_t netloc_len;
+    Py_ssize_t path;		/* path */
+    Py_ssize_t path_len;
+    Py_ssize_t params;		/* parameters */
+    Py_ssize_t params_len;
+    Py_ssize_t query;		/* query */
+    Py_ssize_t query_len;
+    Py_ssize_t fragment;	/* fragment */
+    Py_ssize_t fragment_len;
 
     /* Flags */
     short path_normalized;	/* Is path normalized ? */
